@@ -12,12 +12,14 @@ except NameError:
 
 if __PYRAD_SETUP__:
     import sys as _sys
+
     _sys.stderr.write("Running from Pyrad source directory.\n")
     del _sys
 else:
 
     # Make sure that deprecation warnings get printed by default
     import warnings as _warnings
+
     _warnings.simplefilter("always", DeprecationWarning)
 
     # print out helpful message if build fails or importing from source tree
@@ -25,11 +27,12 @@ else:
     # from . import __check_build
 
     # import subpackages
-    from . import graph
-    from . import io
-    from . import proc
-    from . import prod
-    from . import util
-    from . import flow
+    from . import graph  # noqa
+    from . import io  # noqa
+    from . import proc  # noqa
+    from . import prod  # noqa
+    from . import util  # noqa
+    from . import flow  # noqa
+
     # root level functions
     # non at the moment
