@@ -15,6 +15,7 @@ Functions to control the Pyrad data processing flow
 
 """
 
-from .flow_control import main, main_rt
+from .flow_control import main, main_rt  # noqa
+from .flow_control import main_gecsx  # noqa
 
-__all__ = [s for s in dir() if not s.startswith('_')]
+__all__ = [s for s in dir() if not s.startswith("_")]
