@@ -16,28 +16,40 @@ Functions to plot Pyrad datasets
 
 """
 
+import pyart
+import matplotlib.pyplot as plt
+import matplotlib.dates as mdates
 from warnings import warn
 
 import numpy as np
 import datetime
 
 import matplotlib as mpl
-mpl.use('Agg')
+
+mpl.use("Agg")
 
 # Increase a bit font size
-mpl.rcParams.update({'font.size': 16})
-mpl.rcParams.update({'font.family':  "sans-serif"})
-
-import matplotlib.dates as mdates
-import matplotlib.pyplot as plt
-
-import pyart
+mpl.rcParams.update({"font.size": 16})
+mpl.rcParams.update({"font.family": "sans-serif"})
 
 
-def plot_timeseries(tvec, data_list, fname_list, labelx='Time [UTC]',
-                    labely='Value', labels=['Sensor'], title='Time Series',
-                    period=0, timeformat=None, colors=None, linestyles=None,
-                    markers=None, ymin=None, ymax=None, dpi=72):
+def plot_timeseries(
+    tvec,
+    data_list,
+    fname_list,
+    labelx="Time [UTC]",
+    labely="Value",
+    labels=["Sensor"],
+    title="Time Series",
+    period=0,
+    timeformat=None,
+    colors=None,
+    linestyles=None,
+    markers=None,
+    ymin=None,
+    ymax=None,
+    dpi=72,
+):
     """
     plots a time series
 
@@ -85,17 +97,18 @@ def plot_timeseries(tvec, data_list, fname_list, labelx='Time [UTC]',
     2018.03.05 -jgr- added x-limit of x axis to avoid unwanted error messages
 
     """
+    tvec = np.array(tvec)  # convert  from pandas if needed
     if period > 0:
         for i, data in enumerate(data_list):
-            data *= (period/3600.)
+            data *= period / 3600.0
             data_list[i] = np.ma.cumsum(data)
 
     fig, ax = plt.subplots(figsize=[10, 6], dpi=dpi)
 
     lab = None
     col = None
-    lstyle = '--'
-    marker = 'o'
+    lstyle = "--"
+    marker = "o"
 
     for i, data in enumerate(data_list):
         if labels is not None:
@@ -106,8 +119,7 @@ def plot_timeseries(tvec, data_list, fname_list, labelx='Time [UTC]',
             lstyle = linestyles[i]
         if markers is not None:
             marker = markers[i]
-        ax.plot(tvec, data, label=lab, color=col, linestyle=lstyle,
-                marker=marker)
+        ax.plot(tvec, data, label=lab, color=col, linestyle=lstyle, marker=marker)
 
     ax.set_title(title)
     ax.set_xlabel(labelx)
@@ -135,11 +147,23 @@ def plot_timeseries(tvec, data_list, fname_list, labelx='Time [UTC]',
     return fname_list
 
 
-def plot_timeseries_comp(date1, value1, date2, value2, fname_list,
-                         labelx='Time [UTC]', labely='Value',
-                         label1='Sensor 1', label2='Sensor 2',
-                         titl='Time Series Comparison', period1=0, period2=0,
-                         ymin=None, ymax=None, dpi=72):
+def plot_timeseries_comp(
+    date1,
+    value1,
+    date2,
+    value2,
+    fname_list,
+    labelx="Time [UTC]",
+    labely="Value",
+    label1="Sensor 1",
+    label2="Sensor 2",
+    titl="Time Series Comparison",
+    period1=0,
+    period2=0,
+    ymin=None,
+    ymax=None,
+    dpi=72,
+):
     """
     plots 2 time series in the same graph
 
@@ -184,16 +208,16 @@ def plot_timeseries_comp(date1, value1, date2, value2, fname_list,
     """
     if (period1 > 0) and (period2 > 0):
         # TODO: document this and check (sometimes artefacts)
-        value1 *= (period1/3600.)
+        value1 *= period1 / 3600.0
         value1 = np.ma.cumsum(value1)
 
-        value2 *= (period2/3600.)
+        value2 *= period2 / 3600.0
         value2 = np.ma.cumsum(value2)
 
     fig, ax = plt.subplots(figsize=[10, 6.5], dpi=dpi)
-    ax.plot(date1, value1, 'b', label=label1, linestyle='--', marker='o')
-    ax.plot(date2, value2, 'r', label=label2, linestyle='--', marker='s')
-    ax.legend(loc='best')
+    ax.plot(date1, value1, "b", label=label1, linestyle="--", marker="o")
+    ax.plot(date2, value2, "r", label=label2, linestyle="--", marker="s")
+    ax.legend(loc="best")
     ax.set_xlabel(labelx)
     ax.set_ylabel(labely)
     ax.set_title(titl)
@@ -217,10 +241,24 @@ def plot_timeseries_comp(date1, value1, date2, value2, fname_list,
     return fname_list
 
 
-def plot_monitoring_ts(date, np_t, cquant, lquant, hquant, field_name,
-                       fname_list, ref_value=None, vmin=None, vmax=None,
-                       np_min=0, labelx='Time [UTC]', labely='Value',
-                       titl='Time Series', dpi=72, plot_until_year_end = False):
+def plot_monitoring_ts(
+    date,
+    np_t,
+    cquant,
+    lquant,
+    hquant,
+    field_name,
+    fname_list,
+    ref_value=None,
+    vmin=None,
+    vmax=None,
+    np_min=0,
+    labelx="Time [UTC]",
+    labely="Value",
+    titl="Time Series",
+    dpi=72,
+    plot_until_year_end=False,
+):
     """
     plots a time series of monitoring data
 
@@ -289,48 +327,43 @@ def plot_monitoring_ts(date, np_t, cquant, lquant, hquant, field_name,
     fig = plt.figure(figsize=[15, 13], dpi=dpi)
 
     ax = fig.add_subplot(2, 1, 1)
-    ax.plot(date_plt, cquant_plt, 'x-')
-    ax.plot(date_plt, lquant_plt, 'rx-')
-    ax.plot(date_plt, hquant_plt, 'rx-')
+    ax.plot(date_plt, cquant_plt, "x-")
+    ax.plot(date_plt, lquant_plt, "rx-")
+    ax.plot(date_plt, hquant_plt, "rx-")
     if ref_value is not None:
-        ax.plot(date_plt, np.zeros(len(date_plt))+ref_value, 'k--')
+        ax.plot(date_plt, np.zeros(len(date_plt)) + ref_value, "k--")
     ax.set_ylabel(labely)
     ax.set_title(titl)
     ax.set_ylim([vmin, vmax])
     if plot_until_year_end:
         t0 = date_plt[0]
-        tend = datetime.datetime(year = t0.year, 
-                                 month = 12,
-                                 day = 31, 
-                                 hour = 23, 
-                                 minute = 59)
+        tend = datetime.datetime(year=t0.year, month=12, day=31, hour=23, minute=59)
         ax.set_xlim([t0, tend])
     else:
         # tight x axis
-        ax.autoscale(enable=True, axis='x', tight=True)
-    
+        ax.autoscale(enable=True, axis="x", tight=True)
+
     ax.grid(True)
 
     ax = fig.add_subplot(2, 1, 2)
-    ax.plot(date, np_t, 'x-')
+    ax.plot(date, np_t, "x-")
 
     if np_min is not None:
-        ax.plot(date, np.zeros(len(date))+np_min, 'k--')
+        ax.plot(date, np.zeros(len(date)) + np_min, "k--")
 
     if plot_until_year_end:
-         ax.set_xlim([t0, tend])
+        ax.set_xlim([t0, tend])
     else:
         # tight x axis
-        ax.autoscale(enable=True, axis='x', tight=True)
+        ax.autoscale(enable=True, axis="x", tight=True)
 
-    ax.set_ylabel('Number of Samples')
+    ax.set_ylabel("Number of Samples")
     ax.set_xlabel(labelx)
 
     # rotates and right aligns the x labels, and moves the bottom of the
     # axes up to make room for them
     fig.autofmt_xdate()
 
-    
     for fname in fname_list:
         fig.savefig(fname, dpi=dpi)
     plt.close(fig)
@@ -338,14 +371,26 @@ def plot_monitoring_ts(date, np_t, cquant, lquant, hquant, field_name,
     return fname_list
 
 
-def plot_intercomp_scores_ts(date_vec, np_vec, meanbias_vec, medianbias_vec,
-                             quant25bias_vec, quant75bias_vec, modebias_vec,
-                             corr_vec, slope_vec, intercep_vec,
-                             intercep_slope1_vec, fname_list, ref_value=0.,
-                             np_min=0, corr_min=0.,
-                             labelx='Time UTC',
-                             titl='RADAR001-RADAR002 intercomparison',
-                             dpi=72):
+def plot_intercomp_scores_ts(
+    date_vec,
+    np_vec,
+    meanbias_vec,
+    medianbias_vec,
+    quant25bias_vec,
+    quant75bias_vec,
+    modebias_vec,
+    corr_vec,
+    slope_vec,
+    intercep_vec,
+    intercep_slope1_vec,
+    fname_list,
+    ref_value=0.0,
+    np_min=0,
+    corr_min=0.0,
+    labelx="Time UTC",
+    titl="RADAR001-RADAR002 intercomparison",
+    dpi=72,
+):
     """
     plots a time series of radar intercomparison scores
 
@@ -428,59 +473,59 @@ def plot_intercomp_scores_ts(date_vec, np_vec, meanbias_vec, medianbias_vec,
     fig = plt.figure(figsize=[10, 20], dpi=dpi)
 
     ax = fig.add_subplot(4, 1, 1)
-    ax.plot(date_plt, medianbias_plt, 'bx-', label='median')
-    ax.plot(date_plt, meanbias_plt, 'rx-', label='mean')
-    ax.plot(date_plt, modebias_plt, 'gx-', label='mode')
-    ax.plot(date_plt, intercep_plt, 'yx-', label='intercep of slope 1 LR')
+    ax.plot(date_plt, medianbias_plt, "bx-", label="median")
+    ax.plot(date_plt, meanbias_plt, "rx-", label="mean")
+    ax.plot(date_plt, modebias_plt, "gx-", label="mode")
+    ax.plot(date_plt, intercep_plt, "yx-", label="intercep of slope 1 LR")
     if ref_value is not None:
-        ax.plot(date_plt, np.zeros(len(date_plt))+ref_value, 'k--')
+        ax.plot(date_plt, np.zeros(len(date_plt)) + ref_value, "k--")
     # plt.legend(loc='best')
-    ax.set_ylabel('bias [dB]')
+    ax.set_ylabel("bias [dB]")
     ax.set_title(titl)
-    ax.set_ylim([-5., 5.])
+    ax.set_ylim([-5.0, 5.0])
 
     # tight x axis
-    ax.autoscale(enable=True, axis='x', tight=True)
+    ax.autoscale(enable=True, axis="x", tight=True)
     ax.grid(True)
 
     ax = fig.add_subplot(4, 1, 2)
-    ax.plot(date_plt, medianbias_plt, 'bx-', label='median')
-    ax.plot(date_plt, quant25bias_plt, 'rx-', label='25-percentile')
-    ax.plot(date_plt, quant75bias_plt, 'rx-', label='75-percentile')
+    ax.plot(date_plt, medianbias_plt, "bx-", label="median")
+    ax.plot(date_plt, quant25bias_plt, "rx-", label="25-percentile")
+    ax.plot(date_plt, quant75bias_plt, "rx-", label="75-percentile")
     if ref_value is not None:
-        ax.plot(date_plt, np.zeros(len(date_plt))+ref_value, 'k--')
+        ax.plot(date_plt, np.zeros(len(date_plt)) + ref_value, "k--")
     # plt.legend(loc='best')
-    ax.set_ylabel('bias [dB]')
-    ax.set_ylim([-5., 5.])
+    ax.set_ylabel("bias [dB]")
+    ax.set_ylim([-5.0, 5.0])
 
     # tight x axis
-    ax.autoscale(enable=True, axis='x', tight=True)
+    ax.autoscale(enable=True, axis="x", tight=True)
     ax.grid(True)
 
     ax = fig.add_subplot(4, 1, 3)
-    ax.plot(date_corr, corr_plt, 'bx-')
+    ax.plot(date_corr, corr_plt, "bx-")
 
     if corr_min > 0:
-        ax.plot(date_corr, np.zeros(len(date_corr))+corr_min, 'k--')
+        ax.plot(date_corr, np.zeros(len(date_corr)) + corr_min, "k--")
 
-    ax.set_ylabel('correlation')
-    ax.set_ylim([0., 1.])
+    ax.set_ylabel("correlation")
+    ax.set_ylim([0.0, 1.0])
 
     # tight x axis
-    ax.autoscale(enable=True, axis='x', tight=True)
+    ax.autoscale(enable=True, axis="x", tight=True)
     ax.grid(True)
 
     ax = fig.add_subplot(4, 1, 4)
-    ax.plot(date2, np_vec, 'bx-')
+    ax.plot(date2, np_vec, "bx-")
 
     if np_min > 0:
-        ax.plot(date2, np.zeros(len(date2))+np_min, 'k--')
+        ax.plot(date2, np.zeros(len(date2)) + np_min, "k--")
 
-    ax.set_ylabel('Number of Samples')
+    ax.set_ylabel("Number of Samples")
     ax.set_xlabel(labelx)
 
     # tight x axis
-    ax.autoscale(enable=True, axis='x', tight=True)
+    ax.autoscale(enable=True, axis="x", tight=True)
 
     # rotates and right aligns the x labels, and moves the bottom of the
     # axes up to make room for them
@@ -493,9 +538,19 @@ def plot_intercomp_scores_ts(date_vec, np_vec, meanbias_vec, medianbias_vec,
     return fname_list
 
 
-def plot_ml_ts(dt_ml_arr, ml_top_avg_arr, ml_top_std_arr, thick_avg_arr,
-               thick_std_arr, nrays_valid_arr, nrays_total_arr, fname_list,
-               labelx='Time UTC', titl='Melting layer time series', dpi=72):
+def plot_ml_ts(
+    dt_ml_arr,
+    ml_top_avg_arr,
+    ml_top_std_arr,
+    thick_avg_arr,
+    thick_std_arr,
+    nrays_valid_arr,
+    nrays_total_arr,
+    fname_list,
+    labelx="Time UTC",
+    titl="Melting layer time series",
+    dpi=72,
+):
     """
     plots a time series of melting layer data
 
@@ -534,43 +589,43 @@ def plot_ml_ts(dt_ml_arr, ml_top_avg_arr, ml_top_std_arr, thick_avg_arr,
     fig = plt.figure(figsize=[10, 15], dpi=dpi)
 
     ax = fig.add_subplot(3, 1, 1)
-    ax.plot(dt_ml_arr, ml_top_avg_arr, 'bx-', label='avg')
-    ax.plot(dt_ml_arr, ml_top_avg_arr+ml_top_std_arr, 'rx-', label='avg+std')
-    ax.plot(dt_ml_arr, ml_top_avg_arr-ml_top_std_arr, 'rx-', label='avg-std')
+    ax.plot(dt_ml_arr, ml_top_avg_arr, "bx-", label="avg")
+    ax.plot(dt_ml_arr, ml_top_avg_arr + ml_top_std_arr, "rx-", label="avg+std")
+    ax.plot(dt_ml_arr, ml_top_avg_arr - ml_top_std_arr, "rx-", label="avg-std")
     # plt.legend(loc='best')
-    ax.set_ylabel('Top height [m MSL]')
+    ax.set_ylabel("Top height [m MSL]")
     ax.set_title(titl)
-    ax.set_ylim([0., 6000.])
+    ax.set_ylim([0.0, 6000.0])
     ax.set_xlim([dt_ml_arr[0], dt_ml_arr[-1]])
 
     # tight x axis
-    ax.autoscale(enable=True, axis='x', tight=True)
+    ax.autoscale(enable=True, axis="x", tight=True)
     ax.grid(True)
 
     ax = fig.add_subplot(3, 1, 2)
-    ax.plot(dt_ml_arr, thick_avg_arr, 'bx-', label='avg')
-    ax.plot(dt_ml_arr, thick_avg_arr+thick_std_arr, 'rx-', label='avg+std')
-    ax.plot(dt_ml_arr, thick_avg_arr-thick_std_arr, 'rx-', label='avg-std')
+    ax.plot(dt_ml_arr, thick_avg_arr, "bx-", label="avg")
+    ax.plot(dt_ml_arr, thick_avg_arr + thick_std_arr, "rx-", label="avg+std")
+    ax.plot(dt_ml_arr, thick_avg_arr - thick_std_arr, "rx-", label="avg-std")
     # plt.legend(loc='best')
-    ax.set_ylabel('Thickness [m]')
-    ax.set_ylim([0., 3000.])
+    ax.set_ylabel("Thickness [m]")
+    ax.set_ylim([0.0, 3000.0])
     ax.set_xlim([dt_ml_arr[0], dt_ml_arr[-1]])
 
     # tight x axis
-    ax.autoscale(enable=True, axis='x', tight=True)
+    ax.autoscale(enable=True, axis="x", tight=True)
     ax.grid(True)
 
     ax = fig.add_subplot(3, 1, 3)
-    ax.plot(dt_ml_arr, nrays_valid_arr, 'bx-', label='N valid rays')
-    ax.plot(dt_ml_arr, nrays_total_arr, 'rx-', label='rays total')
+    ax.plot(dt_ml_arr, nrays_valid_arr, "bx-", label="N valid rays")
+    ax.plot(dt_ml_arr, nrays_total_arr, "rx-", label="rays total")
     # plt.legend(loc='best')
-    ax.set_ylabel('Rays')
+    ax.set_ylabel("Rays")
     ax.set_xlabel(labelx)
-    ax.set_ylim([0, np.max(nrays_total_arr)+5])
+    ax.set_ylim([0, np.max(nrays_total_arr) + 5])
     ax.set_xlim([dt_ml_arr[0], dt_ml_arr[-1]])
 
     # tight x axis
-    ax.autoscale(enable=True, axis='x', tight=True)
+    ax.autoscale(enable=True, axis="x", tight=True)
     ax.grid(True)
 
     # rotates and right aligns the x labels, and moves the bottom of the
@@ -584,8 +639,14 @@ def plot_ml_ts(dt_ml_arr, ml_top_avg_arr, ml_top_std_arr, thick_avg_arr,
     return fname_list
 
 
-def plot_sun_retrieval_ts(sun_retrieval, data_type, fname_list, labelx='Date',
-                          titl='Sun retrieval Time Series', dpi=72):
+def plot_sun_retrieval_ts(
+    sun_retrieval,
+    data_type,
+    fname_list,
+    labelx="Date",
+    titl="Sun retrieval Time Series",
+    dpi=72,
+):
     """
     plots sun retrieval time series series
 
@@ -613,119 +674,120 @@ def plot_sun_retrieval_ts(sun_retrieval, data_type, fname_list, labelx='Date',
     value_std = None
     ref = None
     date = sun_retrieval[1]
-    if data_type == 'nhits_h':
+    if data_type == "nhits_h":
         value = sun_retrieval[2]
-        labely = 'Number of sun hits H channel'
+        labely = "Number of sun hits H channel"
         vmin = 0
-        vmax = np.max(sun_retrieval[2])+1
-    elif data_type == 'el_width_h':
+        vmax = np.max(sun_retrieval[2]) + 1
+    elif data_type == "el_width_h":
         value = sun_retrieval[3]
-        labely = 'Elevation beamwidth H channel (Deg)'
-        vmin = 0.
-        vmax = 4.
-    elif data_type == 'az_width_h':
+        labely = "Elevation beamwidth H channel (Deg)"
+        vmin = 0.0
+        vmax = 4.0
+    elif data_type == "az_width_h":
         value = sun_retrieval[4]
-        labely = 'Azimuth beamwidth H channel (Deg)'
-        vmin = 0.
-        vmax = 4.
-    elif data_type == 'el_bias_h':
+        labely = "Azimuth beamwidth H channel (Deg)"
+        vmin = 0.0
+        vmax = 4.0
+    elif data_type == "el_bias_h":
         value = sun_retrieval[5]
         ref = np.zeros(len(value))
-        labely = 'Elevation pointing bias H channel (Deg)'
-        vmin = -2.
-        vmax = 2.
-    elif data_type == 'az_bias_h':
+        labely = "Elevation pointing bias H channel (Deg)"
+        vmin = -2.0
+        vmax = 2.0
+    elif data_type == "az_bias_h":
         value = sun_retrieval[6]
         ref = np.zeros(len(value))
-        labely = 'Azimuth pointing bias H channel (Deg)'
-        vmin = -2.
-        vmax = 2.
-    elif data_type == 'dBm_sun_est':
+        labely = "Azimuth pointing bias H channel (Deg)"
+        vmin = -2.0
+        vmax = 2.0
+    elif data_type == "dBm_sun_est":
         value = sun_retrieval[7]
         value_std = sun_retrieval[8]
-        labely = 'Sun Power H channel (dBm)'
-        vmin = -110.
-        vmax = -90.
-    elif data_type == 'rx_bias_h':
-        value = (10.*np.ma.log10(sun_retrieval[9]) -
-                 10.*np.ma.log10(sun_retrieval[21]))
+        labely = "Sun Power H channel (dBm)"
+        vmin = -110.0
+        vmax = -90.0
+    elif data_type == "rx_bias_h":
+        value = 10.0 * np.ma.log10(sun_retrieval[9]) - 10.0 * np.ma.log10(
+            sun_retrieval[21]
+        )
         value_std = sun_retrieval[8]
         ref = np.zeros(len(value))
-        labely = 'Receiver bias H channel (dB)'
-        vmin = -5.
-        vmax = 5.
-    elif data_type == 'sf_h':
-        value = 10.*np.ma.log10(sun_retrieval[9])
+        labely = "Receiver bias H channel (dB)"
+        vmin = -5.0
+        vmax = 5.0
+    elif data_type == "sf_h":
+        value = 10.0 * np.ma.log10(sun_retrieval[9])
         # value_std = sun_retrieval[8]
-        ref = 10.*np.ma.log10(sun_retrieval[21])
-        labely = 'Observed solar flux H channel (dB(sfu))'
-        vmin = 15.
-        vmax = 30.
-    elif data_type == 'nhits_v':
+        ref = 10.0 * np.ma.log10(sun_retrieval[21])
+        labely = "Observed solar flux H channel (dB(sfu))"
+        vmin = 15.0
+        vmax = 30.0
+    elif data_type == "nhits_v":
         value = sun_retrieval[10]
-        labely = 'Number of sun hits V channel'
+        labely = "Number of sun hits V channel"
         vmin = 0
-        vmax = np.max(sun_retrieval[10])+1
-    elif data_type == 'el_width_v':
+        vmax = np.max(sun_retrieval[10]) + 1
+    elif data_type == "el_width_v":
         value = sun_retrieval[11]
-        labely = 'Elevation beamwidth V channel (Deg)'
-        vmin = 0.
-        vmax = 4.
-    elif data_type == 'az_width_v':
+        labely = "Elevation beamwidth V channel (Deg)"
+        vmin = 0.0
+        vmax = 4.0
+    elif data_type == "az_width_v":
         value = sun_retrieval[12]
-        labely = 'Azimuth beamwidth V channel (Deg)'
-        vmin = 0.
-        vmax = 4.
-    elif data_type == 'el_bias_v':
+        labely = "Azimuth beamwidth V channel (Deg)"
+        vmin = 0.0
+        vmax = 4.0
+    elif data_type == "el_bias_v":
         value = sun_retrieval[13]
         ref = np.zeros(len(value))
-        labely = 'Elevation pointing bias V channel (Deg)'
-        vmin = -2.
-        vmax = 2.
-    elif data_type == 'az_bias_v':
+        labely = "Elevation pointing bias V channel (Deg)"
+        vmin = -2.0
+        vmax = 2.0
+    elif data_type == "az_bias_v":
         value = sun_retrieval[14]
         ref = np.zeros(len(value))
-        labely = 'Azimuth pointing bias V channel (Deg)'
-        vmin = -2.
-        vmax = 2.
-    elif data_type == 'dBmv_sun_est':
+        labely = "Azimuth pointing bias V channel (Deg)"
+        vmin = -2.0
+        vmax = 2.0
+    elif data_type == "dBmv_sun_est":
         value = sun_retrieval[15]
         value_std = sun_retrieval[16]
-        labely = 'Sun Power V channel (dBm)'
-        vmin = -110.
-        vmax = -90.
-    elif data_type == 'rx_bias_v':
-        value = (10.*np.ma.log10(sun_retrieval[17]) -
-                 10.*np.ma.log10(sun_retrieval[21]))
+        labely = "Sun Power V channel (dBm)"
+        vmin = -110.0
+        vmax = -90.0
+    elif data_type == "rx_bias_v":
+        value = 10.0 * np.ma.log10(sun_retrieval[17]) - 10.0 * np.ma.log10(
+            sun_retrieval[21]
+        )
         value_std = sun_retrieval[16]
         ref = np.zeros(len(value))
-        labely = 'Receiver bias V channel (dB)'
-        vmin = -5.
-        vmax = 5.
-    elif data_type == 'sf_v':
-        value = 10.*np.ma.log10(sun_retrieval[17])
+        labely = "Receiver bias V channel (dB)"
+        vmin = -5.0
+        vmax = 5.0
+    elif data_type == "sf_v":
+        value = 10.0 * np.ma.log10(sun_retrieval[17])
         # value_std = sun_retrieval[16]
-        ref = 10.*np.ma.log10(sun_retrieval[21])
-        labely = 'Observed solar flux V channel (dB(sfu))'
-        vmin = 15.
-        vmax = 30.
-    elif data_type == 'nhits_zdr':
+        ref = 10.0 * np.ma.log10(sun_retrieval[21])
+        labely = "Observed solar flux V channel (dB(sfu))"
+        vmin = 15.0
+        vmax = 30.0
+    elif data_type == "nhits_zdr":
         value = sun_retrieval[18]
-        labely = 'Number of sun hits ZDR'
+        labely = "Number of sun hits ZDR"
         vmin = 0
-        vmax = np.max(sun_retrieval[18])+1
-    elif data_type == 'ZDR_sun_est':
+        vmax = np.max(sun_retrieval[18]) + 1
+    elif data_type == "ZDR_sun_est":
         value = sun_retrieval[19]
         value_std = sun_retrieval[20]
         ref = np.zeros(len(value))
-        labely = 'Sun ZDR (dB)'
-        vmin = -2.
-        vmax = 2.
+        labely = "Sun ZDR (dB)"
+        vmin = -2.0
+        vmax = 2.0
 
     mask = np.ma.getmaskarray(value)
     if mask.all():
-        warn('Unable to create figure '+' '.join(fname_list) +
-             '. No valid data')
+        warn("Unable to create figure " + " ".join(fname_list) + ". No valid data")
         return None
 
     # plot only valid data (but keep first and last date)
@@ -742,7 +804,7 @@ def plot_sun_retrieval_ts(sun_retrieval, data_type, fname_list, labelx='Date',
         date_plt = np.ma.append(date_plt, date2[-1])
 
     fig, ax = plt.subplots(figsize=[10, 6], dpi=dpi)
-    ax.plot(date_plt, value_plt, 'x-')
+    ax.plot(date_plt, value_plt, "x-")
     if value_std is not None:
         value_std_plt = value_std[isvalid]
         if not isvalid[0]:
@@ -750,22 +812,22 @@ def plot_sun_retrieval_ts(sun_retrieval, data_type, fname_list, labelx='Date',
         if not isvalid[-1]:
             value_std_plt = np.ma.append(value_std_plt, np.ma.masked)
 
-        ax.plot(date_plt, value_plt+value_std_plt, 'rx-')
-        ax.plot(date_plt, value_plt-value_std_plt, 'rx-')
+        ax.plot(date_plt, value_plt + value_std_plt, "rx-")
+        ax.plot(date_plt, value_plt - value_std_plt, "rx-")
     if ref is not None:
         ref_plt = ref[isvalid]
         if not isvalid[0]:
             ref_plt = np.ma.append(ref[0], ref_plt)
         if not isvalid[-1]:
             ref_plt = np.ma.append(ref_plt, ref[-1])
-        ax.plot(date_plt, ref_plt, 'k--')
+        ax.plot(date_plt, ref_plt, "k--")
     ax.set_xlabel(labelx)
     ax.set_ylabel(labely)
     ax.set_title(titl)
     ax.set_ylim([vmin, vmax])
     ax.set_xlim([date_plt[0], date_plt[-1]])
     # tight x axis
-    ax.autoscale(enable=True, axis='x', tight=True)
+    ax.autoscale(enable=True, axis="x", tight=True)
     ax.grid(True)
 
     # rotates and right aligns the x labels, and moves the bottom of the
