@@ -43,8 +43,9 @@ class TimeSeries(object):
 
     """
 
-    def __init__(self, desc, timevec=None, timeformat=None, maxlength=None,
-                 datatype=""):
+    def __init__(
+        self, desc, timevec=None, timeformat=None, maxlength=None, datatype=""
+    ):
         """
         Initalize the object.
 
@@ -60,8 +61,9 @@ class TimeSeries(object):
         self.description = desc
         if timevec is None:
             if maxlength is None:
-                raise Exception("ERROR: Either 'timevec' or 'maxlength'"
-                                " must be defined")
+                raise Exception(
+                    "ERROR: Either 'timevec' or 'maxlength'" " must be defined"
+                )
             self.maxlength = maxlength
             self.time_vector = np.empty(maxlength, dtype=datetime)
             self.num_el = 0
@@ -73,8 +75,16 @@ class TimeSeries(object):
         self.dataseries = []
         self.datatype = datatype
 
-    def add_dataseries(self, label, unit_name, unit, dataseries=None,
-                       plot=True, color=None, linestyle=None):
+    def add_dataseries(
+        self,
+        label,
+        unit_name,
+        unit,
+        dataseries=None,
+        plot=True,
+        color=None,
+        linestyle=None,
+    ):
         """
         Add a new data series to the timeseries object.
         The length of the data vector must be the same as the
@@ -83,13 +93,22 @@ class TimeSeries(object):
 
         if dataseries is not None:
             if len(dataseries) != self.num_el:
-                raise Exception("ERROR: Number of data series sample do "
-                                "not correspond to time vector ('%s')" % label)
+                raise Exception(
+                    "ERROR: Number of data series sample do "
+                    "not correspond to time vector ('%s')" % label
+                )
         else:
             dataseries = np.ma.empty(self.maxlength)
 
-        ds = _DataSeries(label, unit_name, unit, dataseries,
-                         plot=plot, color=color, linestyle=linestyle)
+        ds = _DataSeries(
+            label,
+            unit_name,
+            unit,
+            dataseries,
+            plot=plot,
+            color=color,
+            linestyle=linestyle,
+        )
         self.dataseries.append(ds)
 
     def add_timesample(self, dt, values):
@@ -98,8 +117,9 @@ class TimeSeries(object):
         """
 
         if self.num_el + 1 > self.maxlength:  # jgr changed from >=
-            raise Exception("ERROR: Cannot add time series sample. Max"
-                            " length reached.")
+            raise Exception(
+                "ERROR: Cannot add time series sample. Max" " length reached."
+            )
 
         self.time_vector[self.num_el] = dt
         for val, ds in zip(values, self.dataseries):
@@ -120,12 +140,15 @@ class TimeSeries(object):
 
         print("# Weather radar timeseries data file", file=tsfile)
         print("# Project: MALSplus", file=tsfile)
-        print("# Start : %s UTC" %
-              self.time_vector[0].strftime("%Y-%m-%d %H:%M:%S"),
-              file=tsfile)
-        print("# End   : %s UTC" %
-              self.time_vector[self.num_el-1].strftime("%Y-%m-%d %H:%M:%S"),
-              file=tsfile)
+        print(
+            "# Start : %s UTC" % self.time_vector[0].strftime("%Y-%m-%d %H:%M:%S"),
+            file=tsfile,
+        )
+        print(
+            "# End   : %s UTC"
+            % self.time_vector[self.num_el - 1].strftime("%Y-%m-%d %H:%M:%S"),
+            file=tsfile,
+        )
         print("# Header lines with comments are preceded by '#'", file=tsfile)
         for line in self.description:
             print("# %s" % line, file=tsfile)
@@ -146,18 +169,24 @@ class TimeSeries(object):
             if self.timeformat is None:
                 dt = self.time_vector[i]
                 daystr = dt.strftime("%d-%b-%Y")
-                secs = dt.hour*3600. + dt.minute*60. + dt.second + \
-                    dt.microsecond/1000000.
+                secs = (
+                    dt.hour * 3600.0
+                    + dt.minute * 60.0
+                    + dt.second
+                    + dt.microsecond / 1000000.0
+                )
                 print("%s, %14.4f" % (daystr, secs), end="", file=tsfile)
             else:
-                print(self.time_vector[i].strftime(self.timeformat), end="",
-                      file=tsfile)
+                print(
+                    self.time_vector[i].strftime(self.timeformat), end="", file=tsfile
+                )
 
             for ds in self.dataseries:
                 print(
-                    ", %14.4f"
-                    % (np.ma.filled(ds.data, fill_value=np.nan)[i]),
-                    end="", file=tsfile)
+                    ", %14.4f" % (np.ma.filled(ds.data, fill_value=np.nan)[i]),
+                    end="",
+                    file=tsfile,
+                )
 
             print("", file=tsfile)
 
@@ -176,7 +205,7 @@ class TimeSeries(object):
         for ds in self.dataseries:
             if ds.plot:
                 found = True
-                ds_list.append(ds.data[:self.num_el])
+                ds_list.append(ds.data[: self.num_el])
                 color_list.append(ds.color)
                 lstyle_list.append(ds.linestyle)
                 if labely is None:
@@ -187,15 +216,20 @@ class TimeSeries(object):
 
         print("----- plot to '%s'" % fname)
 
-        title = "Trajectory Time Series %s" % \
-            self.time_vector[0].strftime("%Y-%m-%d")
-        plot_timeseries(self.time_vector[:self.num_el],
-                        ds_list,
-                        [fname], title=title,
-                        labels=None,
-                        labely=labely, timeformat="%H:%M",
-                        colors=color_list, linestyles=lstyle_list,
-                        ymin=ymin, ymax=ymax)
+        title = "Trajectory Time Series %s" % self.time_vector[0].strftime("%Y-%m-%d")
+        plot_timeseries(
+            self.time_vector[: self.num_el],
+            ds_list,
+            [fname],
+            title=title,
+            labels=None,
+            labely=labely,
+            timeformat="%H:%M",
+            colors=color_list,
+            linestyles=lstyle_list,
+            ymin=ymin,
+            ymax=ymax,
+        )
 
     def plot_hist(self, fname, step=None):
         """
@@ -204,14 +238,21 @@ class TimeSeries(object):
         for ds in self.dataseries:
             if ds.plot:
                 bins, values = compute_histogram(
-                    ds.data[:self.num_el], get_fieldname_pyart(self.datatype),
-                    step=step)
-                fname2 = fname.replace('.', '_'+ds.label+'.')
+                    ds.data[: self.num_el],
+                    get_fieldname_pyart(self.datatype),
+                    step=step,
+                )
+                fname2 = fname.replace(".", "_" + ds.label + ".")
                 plot_histogram(
-                    bins, values, [fname2],
+                    bins,
+                    values,
+                    [fname2],
                     labelx="%s [%s]" % (ds.unit_name, ds.unit),
-                    titl=("Trajectory Histogram %s" %
-                          self.time_vector[0].strftime("%Y-%m-%d")))
+                    titl=(
+                        "Trajectory Histogram %s"
+                        % self.time_vector[0].strftime("%Y-%m-%d")
+                    ),
+                )
                 print("----- plot to '%s'" % fname2)
 
 
@@ -220,8 +261,9 @@ class _DataSeries(object):
     Hold a data vector and some meta information.
     """
 
-    def __init__(self, label, unit_name, unit, data, plot=True,
-                 color=None, linestyle=None):
+    def __init__(
+        self, label, unit_name, unit, data, plot=True, color=None, linestyle=None
+    ):
         """
         Initalize the object.
         """
