@@ -25,8 +25,6 @@ Functions to processes IQ data.
 
 from copy import deepcopy
 from warnings import warn
-import numpy as np
-from netCDF4 import num2date
 
 import pyart
 
@@ -59,14 +57,14 @@ def process_raw_iq(procstatus, dscfg, radar_list=None):
     if procstatus != 1:
         return None, None
 
-    for datatypedescr in dscfg['datatype']:
+    for datatypedescr in dscfg["datatype"]:
         radarnr, _, _, _, _ = get_datatype_fields(datatypedescr)
         break
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
-    new_dataset = {'radar_out': deepcopy(radar_list[ind_rad])}
+    new_dataset = {"radar_out": deepcopy(radar_list[ind_rad])}
 
     return new_dataset, ind_rad
 
@@ -84,7 +82,8 @@ def process_pol_variables_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU", "IQvvADU", "IQNADUh" and "IQNADUv"
         subtract_noise : Bool
             If True noise will be subtracted from the signal
         lag : int
@@ -102,7 +101,9 @@ def process_pol_variables_iq(procstatus, dscfg, radar_list=None):
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output fields corresponding to the specified
+        "variables"
+        ""
     ind_rad : int
         radar index
 
@@ -114,41 +115,48 @@ def process_pol_variables_iq(procstatus, dscfg, radar_list=None):
     noise_v_field = None
     signal_h_field = None
     signal_v_field = None
-    for datatypedescr in dscfg['datatype']:
+    for datatypedescr in dscfg["datatype"]:
         radarnr, _, datatype, _, _ = get_datatype_fields(datatypedescr)
-        if datatype == 'IQhhADU':
+        if datatype == "IQhhADU":
             signal_h_field = get_fieldname_pyart(datatype)
-        elif datatype == 'IQvvADU':
+        elif datatype == "IQvvADU":
             signal_v_field = get_fieldname_pyart(datatype)
-        elif datatype == 'IQNADUh':
+        elif datatype == "IQNADUh":
             noise_h_field = get_fieldname_pyart(datatype)
-        elif datatype == 'IQNADUv':
+        elif datatype == "IQNADUv":
             noise_v_field = get_fieldname_pyart(datatype)
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
-    subtract_noise = dscfg.get('subtract_noise', False)
-    lag = dscfg.get('lag', None)
-    direction = dscfg.get('direction', 'negative_away')
-    variables = dscfg.get('variables', ['dBZ'])
-    phase_offset = dscfg.get('phase_offset', 0.)
+    subtract_noise = dscfg.get("subtract_noise", False)
+    lag = dscfg.get("lag", None)
+    direction = dscfg.get("direction", "negative_away")
+    variables = dscfg.get("variables", ["dBZ"])
+    phase_offset = dscfg.get("phase_offset", 0.0)
 
     fields_list = []
     for variable in variables:
         fields_list.append(get_fieldname_pyart(variable))
 
     radar = pyart.retrieve.compute_pol_variables_iq(
-        radar, fields_list, subtract_noise=subtract_noise, lag=lag,
-        direction=direction, phase_offset=phase_offset,
-        signal_h_field=signal_h_field, signal_v_field=signal_v_field,
-        noise_h_field=noise_h_field, noise_v_field=noise_v_field)
+        radar,
+        fields_list,
+        subtract_noise=subtract_noise,
+        lag=lag,
+        direction=direction,
+        phase_offset=phase_offset,
+        signal_h_field=signal_h_field,
+        signal_v_field=signal_v_field,
+        noise_h_field=noise_h_field,
+        noise_v_field=noise_v_field,
+    )
 
     # prepare for exit
-    new_dataset = {'radar_out': radar}
+    new_dataset = {"radar_out": radar}
 
     return new_dataset, ind_rad
 
@@ -166,7 +174,9 @@ def process_reflectivity_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU" or "IQvvADU", and,
+            "IQNADUh" or "IQNADUv"
         subtract_noise : Bool
             If True noise will be subtracted from the signal
     radar_list : list of spectra objects
@@ -175,7 +185,9 @@ def process_reflectivity_iq(procstatus, dscfg, radar_list=None):
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output field
+        "dBZ" if "IQhhADU" and "IQNADUh" are specified
+        "dBZv" if "IQvvADU" and "IQNADUv" are specified
     ind_rad : int
         radar index
 
@@ -186,41 +198,43 @@ def process_reflectivity_iq(procstatus, dscfg, radar_list=None):
 
     noise_field = None
     signal_field = None
-    for datatypedescr in dscfg['datatype']:
+    for datatypedescr in dscfg["datatype"]:
         radarnr, _, datatype, _, _ = get_datatype_fields(datatypedescr)
-        if datatype in ('IQhhADU', 'IQvvADU'):
+        if datatype in ("IQhhADU", "IQvvADU"):
             signal_field = get_fieldname_pyart(datatype)
-        elif datatype in ('IQNADUh', 'IQNADUv'):
+        elif datatype in ("IQNADUh", "IQNADUv"):
             noise_field = get_fieldname_pyart(datatype)
 
     if signal_field is None:
-        warn('Signal field must be specified')
+        warn("Signal field must be specified")
         return None, None
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
     if signal_field not in radar.fields:
-        warn('Unable to obtain reflectivity. Missing field ' +
-             signal_field)
+        warn("Unable to obtain reflectivity. Missing field " + signal_field)
         return None, None
 
-    subtract_noise = dscfg.get('subtract_noise', False)
+    subtract_noise = dscfg.get("subtract_noise", False)
 
     dBZ = pyart.retrieve.compute_reflectivity_iq(
-        radar, subtract_noise=subtract_noise, signal_field=signal_field,
-        noise_field=noise_field)
+        radar,
+        subtract_noise=subtract_noise,
+        signal_field=signal_field,
+        noise_field=noise_field,
+    )
 
-    reflectivity_field = 'reflectivity'
-    if signal_field in ('IQ_vv_ADU',):
-        reflectivity_field += '_vv'
+    reflectivity_field = "reflectivity"
+    if signal_field in ("IQ_vv_ADU",):
+        reflectivity_field += "_vv"
 
     # prepare for exit
-    new_dataset = {'radar_out': pyart.util.radar_from_spectra(radar)}
-    new_dataset['radar_out'].add_field(reflectivity_field, dBZ)
+    new_dataset = {"radar_out": pyart.util.radar_from_spectra(radar)}
+    new_dataset["radar_out"].add_field(reflectivity_field, dBZ)
 
     return new_dataset, ind_rad
 
@@ -239,14 +253,15 @@ def process_st1_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU" or "IQvvADU"
     radar_list : list of spectra objects
         Optional. list of spectra objects
 
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output field "ST1" (stat_test_lag1)
     ind_rad : int
         radar index
 
@@ -255,29 +270,28 @@ def process_st1_iq(procstatus, dscfg, radar_list=None):
     if procstatus != 1:
         return None, None
 
-    radarnr, _, datatype, _, _ = get_datatype_fields(dscfg['datatype'][0])
+    radarnr, _, datatype, _, _ = get_datatype_fields(dscfg["datatype"][0])
     signal_field = get_fieldname_pyart(datatype)
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
     if signal_field not in radar.fields:
-        warn('Unable to obtain ST1. Missing fields')
+        warn("Unable to obtain ST1. Missing fields")
         return None, None
 
-    st1 = pyart.retrieve.compute_st1_iq(
-        radar, signal_field=signal_field)
+    st1 = pyart.retrieve.compute_st1_iq(radar, signal_field=signal_field)
 
-    st1_field = 'stat_test_lag1'
-    if signal_field == 'IQ_vv_ADU':
-        st1_field += '_vv'
+    st1_field = "stat_test_lag1"
+    if signal_field == "IQ_vv_ADU":
+        st1_field += "_vv"
 
     # prepare for exit
-    new_dataset = {'radar_out': pyart.util.radar_from_spectra(radar)}
-    new_dataset['radar_out'].add_field(st1_field, st1)
+    new_dataset = {"radar_out": pyart.util.radar_from_spectra(radar)}
+    new_dataset["radar_out"].add_field(st1_field, st1)
 
     return new_dataset, ind_rad
 
@@ -296,14 +310,15 @@ def process_st2_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU" or "IQvvADU"
     radar_list : list of spectra objects
         Optional. list of spectra objects
 
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output field "ST2"
     ind_rad : int
         radar index
 
@@ -312,29 +327,28 @@ def process_st2_iq(procstatus, dscfg, radar_list=None):
     if procstatus != 1:
         return None, None
 
-    radarnr, _, datatype, _, _ = get_datatype_fields(dscfg['datatype'][0])
+    radarnr, _, datatype, _, _ = get_datatype_fields(dscfg["datatype"][0])
     signal_field = get_fieldname_pyart(datatype)
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
     if signal_field not in radar.fields:
-        warn('Unable to obtain ST2. Missing fields')
+        warn("Unable to obtain ST2. Missing fields")
         return None, None
 
-    st2 = pyart.retrieve.compute_st2_iq(
-        radar, signal_field=signal_field)
+    st2 = pyart.retrieve.compute_st2_iq(radar, signal_field=signal_field)
 
-    st2_field = 'stat_test_lag2'
-    if signal_field == 'IQ_vv_ADU':
-        st2_field += '_vv'
+    st2_field = "stat_test_lag2"
+    if signal_field == "IQ_vv_ADU":
+        st2_field += "_vv"
 
     # prepare for exit
-    new_dataset = {'radar_out': pyart.util.radar_from_spectra(radar)}
-    new_dataset['radar_out'].add_field(st2_field, st2)
+    new_dataset = {"radar_out": pyart.util.radar_from_spectra(radar)}
+    new_dataset["radar_out"].add_field(st2_field, st2)
 
     return new_dataset, ind_rad
 
@@ -352,14 +366,15 @@ def process_wbn_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU" or "IQvvADU"
     radar_list : list of spectra objects
         Optional. list of spectra objects
 
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output field "WBN" (wide-band noise)
     ind_rad : int
         radar index
 
@@ -368,29 +383,28 @@ def process_wbn_iq(procstatus, dscfg, radar_list=None):
     if procstatus != 1:
         return None, None
 
-    radarnr, _, datatype, _, _ = get_datatype_fields(dscfg['datatype'][0])
+    radarnr, _, datatype, _, _ = get_datatype_fields(dscfg["datatype"][0])
     signal_field = get_fieldname_pyart(datatype)
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
     if signal_field not in radar.fields:
-        warn('Unable to obtain WBN. Missing fields')
+        warn("Unable to obtain WBN. Missing fields")
         return None, None
 
-    wbn = pyart.retrieve.compute_wbn_iq(
-        radar, signal_field=signal_field)
+    wbn = pyart.retrieve.compute_wbn_iq(radar, signal_field=signal_field)
 
-    wbn_field = 'wide_band_noise'
-    if signal_field == 'IQ_vv_ADU':
-        wbn_field += '_vv'
+    wbn_field = "wide_band_noise"
+    if signal_field == "IQ_vv_ADU":
+        wbn_field += "_vv"
 
     # prepare for exit
-    new_dataset = {'radar_out': pyart.util.radar_from_spectra(radar)}
-    new_dataset['radar_out'].add_field(wbn_field, wbn)
+    new_dataset = {"radar_out": pyart.util.radar_from_spectra(radar)}
+    new_dataset["radar_out"].add_field(wbn_field, wbn)
 
     return new_dataset, ind_rad
 
@@ -409,7 +423,8 @@ def process_differential_reflectivity_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU", "IQvvADU", "IQNADUh" and "IQNADUv"
         subtract_noise : Bool
             If True noise will be subtracted from the signal
         lag : int
@@ -420,7 +435,7 @@ def process_differential_reflectivity_iq(procstatus, dscfg, radar_list=None):
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output field "ZDR"
     ind_rad : int
         radar index
 
@@ -433,40 +448,43 @@ def process_differential_reflectivity_iq(procstatus, dscfg, radar_list=None):
     noise_v_field = None
     signal_h_field = None
     signal_v_field = None
-    for datatypedescr in dscfg['datatype']:
+    for datatypedescr in dscfg["datatype"]:
         radarnr, _, datatype, _, _ = get_datatype_fields(datatypedescr)
-        if datatype == 'IQhhADU':
+        if datatype == "IQhhADU":
             signal_h_field = get_fieldname_pyart(datatype)
-        elif datatype == 'IQvvADU':
+        elif datatype == "IQvvADU":
             signal_v_field = get_fieldname_pyart(datatype)
-        elif datatype == 'IQNADUh':
+        elif datatype == "IQNADUh":
             noise_h_field = get_fieldname_pyart(datatype)
-        elif datatype == 'IQNADUv':
+        elif datatype == "IQNADUv":
             noise_v_field = get_fieldname_pyart(datatype)
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
-    if (signal_h_field not in radar.fields or
-            signal_v_field not in radar.fields):
-        warn('Unable to obtain spectral differential reflectivity. ' +
-             'Missing fields')
+    if signal_h_field not in radar.fields or signal_v_field not in radar.fields:
+        warn("Unable to obtain spectral differential reflectivity. " + "Missing fields")
         return None, None
 
-    subtract_noise = dscfg.get('subtract_noise', False)
-    lag = dscfg.get('lag', 0)
+    subtract_noise = dscfg.get("subtract_noise", False)
+    lag = dscfg.get("lag", 0)
 
     zdr = pyart.retrieve.compute_differential_reflectivity_iq(
-        radar, subtract_noise=subtract_noise, lag=lag,
-        signal_h_field=signal_h_field, signal_v_field=signal_v_field,
-        noise_h_field=noise_h_field, noise_v_field=noise_v_field)
+        radar,
+        subtract_noise=subtract_noise,
+        lag=lag,
+        signal_h_field=signal_h_field,
+        signal_v_field=signal_v_field,
+        noise_h_field=noise_h_field,
+        noise_v_field=noise_v_field,
+    )
 
     # prepare for exit
-    new_dataset = {'radar_out': pyart.util.radar_from_spectra(radar)}
-    new_dataset['radar_out'].add_field('differential_reflectivity', zdr)
+    new_dataset = {"radar_out": pyart.util.radar_from_spectra(radar)}
+    new_dataset["radar_out"].add_field("differential_reflectivity", zdr)
 
     return new_dataset, ind_rad
 
@@ -484,14 +502,15 @@ def process_mean_phase_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU" or "IQvvADU"
     radar_list : list of spectra objects
         Optional. list of spectra objects
 
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output field "MPH" (mean_phase)
     ind_rad : int
         radar index
 
@@ -500,29 +519,28 @@ def process_mean_phase_iq(procstatus, dscfg, radar_list=None):
     if procstatus != 1:
         return None, None
 
-    radarnr, _, datatype, _, _ = get_datatype_fields(dscfg['datatype'][0])
+    radarnr, _, datatype, _, _ = get_datatype_fields(dscfg["datatype"][0])
     signal_field = get_fieldname_pyart(datatype)
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
     if signal_field not in radar.fields:
-        warn('Unable to obtain MPH. Missing fields')
+        warn("Unable to obtain MPH. Missing fields")
         return None, None
 
-    mph = pyart.retrieve.compute_mean_phase_iq(
-        radar, signal_field=signal_field)
+    mph = pyart.retrieve.compute_mean_phase_iq(radar, signal_field=signal_field)
 
-    mean_phase_field = 'mean_phase'
-    if signal_field == 'IQ_vv_ADU':
-        mean_phase_field += '_vv'
+    mean_phase_field = "mean_phase"
+    if signal_field == "IQ_vv_ADU":
+        mean_phase_field += "_vv"
 
     # prepare for exit
-    new_dataset = {'radar_out': pyart.util.radar_from_spectra(radar)}
-    new_dataset['radar_out'].add_field(mean_phase_field, mph)
+    new_dataset = {"radar_out": pyart.util.radar_from_spectra(radar)}
+    new_dataset["radar_out"].add_field(mean_phase_field, mph)
 
     return new_dataset, ind_rad
 
@@ -540,7 +558,8 @@ def process_differential_phase_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU" and "IQvvADU"
         phase_offset : float. Dataset keyword
             The system differential phase offset to remove
     radar_list : list of spectra objects
@@ -549,7 +568,7 @@ def process_differential_phase_iq(procstatus, dscfg, radar_list=None):
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output field uPhiDP
     ind_rad : int
         radar index
 
@@ -560,34 +579,35 @@ def process_differential_phase_iq(procstatus, dscfg, radar_list=None):
 
     signal_h_field = None
     signal_v_field = None
-    for datatypedescr in dscfg['datatype']:
+    for datatypedescr in dscfg["datatype"]:
         radarnr, _, datatype, _, _ = get_datatype_fields(datatypedescr)
-        if datatype == 'IQhhADU':
+        if datatype == "IQhhADU":
             signal_h_field = get_fieldname_pyart(datatype)
-        elif datatype == 'IQvvADU':
+        elif datatype == "IQvvADU":
             signal_v_field = get_fieldname_pyart(datatype)
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
-    if (signal_h_field not in radar.fields or
-            signal_v_field not in radar.fields):
-        warn('Unable to obtain PhiDP. Missing fields')
+    if signal_h_field not in radar.fields or signal_v_field not in radar.fields:
+        warn("Unable to obtain PhiDP. Missing fields")
         return None, None
 
-    phase_offset = dscfg.get('phase_offset', 0.)
+    phase_offset = dscfg.get("phase_offset", 0.0)
 
     uphidp = pyart.retrieve.compute_differential_phase_iq(
-        radar, phase_offset=phase_offset, signal_h_field=signal_h_field,
-        signal_v_field=signal_v_field)
+        radar,
+        phase_offset=phase_offset,
+        signal_h_field=signal_h_field,
+        signal_v_field=signal_v_field,
+    )
 
     # prepare for exit
-    new_dataset = {'radar_out': pyart.util.radar_from_spectra(radar)}
-    new_dataset['radar_out'].add_field(
-        'uncorrected_differential_phase', uphidp)
+    new_dataset = {"radar_out": pyart.util.radar_from_spectra(radar)}
+    new_dataset["radar_out"].add_field("uncorrected_differential_phase", uphidp)
 
     return new_dataset, ind_rad
 
@@ -605,7 +625,8 @@ def process_rhohv_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU", "IQvvADU", "IQNADUh" and "IQNADUv"
         subtract_noise : Bool
             If True noise will be subtracted from the signal
         lag : int
@@ -616,7 +637,7 @@ def process_rhohv_iq(procstatus, dscfg, radar_list=None):
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output field "RhoHV"
     ind_rad : int
         radar index
 
@@ -628,39 +649,43 @@ def process_rhohv_iq(procstatus, dscfg, radar_list=None):
     noise_v_field = None
     signal_h_field = None
     signal_v_field = None
-    for datatypedescr in dscfg['datatype']:
+    for datatypedescr in dscfg["datatype"]:
         radarnr, _, datatype, _, _ = get_datatype_fields(datatypedescr)
-        if datatype == 'IQhhADU':
+        if datatype == "IQhhADU":
             signal_h_field = get_fieldname_pyart(datatype)
-        elif datatype == 'IQvvADU':
+        elif datatype == "IQvvADU":
             signal_v_field = get_fieldname_pyart(datatype)
-        elif datatype == 'IQNADUh':
+        elif datatype == "IQNADUh":
             noise_h_field = get_fieldname_pyart(datatype)
-        elif datatype == 'IQNADUv':
+        elif datatype == "IQNADUv":
             noise_v_field = get_fieldname_pyart(datatype)
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
-    if (signal_h_field not in radar.fields or
-            signal_v_field not in radar.fields):
-        warn('Unable to obtain RhoHV. Missing fields')
+    if signal_h_field not in radar.fields or signal_v_field not in radar.fields:
+        warn("Unable to obtain RhoHV. Missing fields")
         return None, None
 
-    subtract_noise = dscfg.get('subtract_noise', False)
-    lag = dscfg.get('lag', 0)
+    subtract_noise = dscfg.get("subtract_noise", False)
+    lag = dscfg.get("lag", 0)
 
     rhohv = pyart.retrieve.compute_rhohv_iq(
-        radar, subtract_noise=subtract_noise, lag=lag,
-        signal_h_field=signal_h_field, signal_v_field=signal_v_field,
-        noise_h_field=noise_h_field, noise_v_field=noise_v_field)
+        radar,
+        subtract_noise=subtract_noise,
+        lag=lag,
+        signal_h_field=signal_h_field,
+        signal_v_field=signal_v_field,
+        noise_h_field=noise_h_field,
+        noise_v_field=noise_v_field,
+    )
 
     # prepare for exit
-    new_dataset = {'radar_out': pyart.util.radar_from_spectra(radar)}
-    new_dataset['radar_out'].add_field('cross_correlation_ratio', rhohv)
+    new_dataset = {"radar_out": pyart.util.radar_from_spectra(radar)}
+    new_dataset["radar_out"].add_field("cross_correlation_ratio", rhohv)
 
     return new_dataset, ind_rad
 
@@ -678,7 +703,8 @@ def process_Doppler_velocity_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU" or "IQvvADU"
         direction : str
             The convention used in the Doppler mean field. Can be
             negative_away or negative_towards
@@ -688,7 +714,8 @@ def process_Doppler_velocity_iq(procstatus, dscfg, radar_list=None):
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output field "V"
+        (if IQhhADU was provided) or "Vv" (if IQvvADU was provided)
     ind_rad : int
         radar index
 
@@ -697,34 +724,34 @@ def process_Doppler_velocity_iq(procstatus, dscfg, radar_list=None):
     if procstatus != 1:
         return None, None
 
-    for datatypedescr in dscfg['datatype']:
+    for datatypedescr in dscfg["datatype"]:
         radarnr, _, datatype, _, _ = get_datatype_fields(datatypedescr)
-        if datatype in ('IQhhADU', 'IQvvADU'):
+        if datatype in ("IQhhADU", "IQvvADU"):
             signal_field = get_fieldname_pyart(datatype)
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
     if signal_field not in radar.fields:
-        warn('Unable to obtain Doppler velocity. ' +
-             'Missing field '+signal_field)
+        warn("Unable to obtain Doppler velocity. " + "Missing field " + signal_field)
         return None, None
 
-    direction = dscfg.get('direction', 'negative_away')
+    direction = dscfg.get("direction", "negative_away")
 
     vel = pyart.retrieve.compute_Doppler_velocity_iq(
-        radar, signal_field=signal_field, direction=direction)
+        radar, signal_field=signal_field, direction=direction
+    )
 
-    vel_field = 'velocity'
-    if signal_field == 'IQ_vv_ADU':
-        vel_field += '_vv'
+    vel_field = "velocity"
+    if signal_field == "IQ_vv_ADU":
+        vel_field += "_vv"
 
     # prepare for exit
-    new_dataset = {'radar_out': pyart.util.radar_from_spectra(radar)}
-    new_dataset['radar_out'].add_field(vel_field, vel)
+    new_dataset = {"radar_out": pyart.util.radar_from_spectra(radar)}
+    new_dataset["radar_out"].add_field(vel_field, vel)
 
     return new_dataset, ind_rad
 
@@ -742,7 +769,8 @@ def process_Doppler_width_iq(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain
+            "IQhhADU" or "IQvvADU"
         subtract_noise : Bool
             If True noise will be subtracted from the signals
         lag : int
@@ -753,7 +781,8 @@ def process_Doppler_width_iq(procstatus, dscfg, radar_list=None):
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output field "W" (if IQhhADU was provided),
+        or "Wv" (if IQvvADU was provided)
     ind_rad : int
         radar index
 
@@ -763,38 +792,45 @@ def process_Doppler_width_iq(procstatus, dscfg, radar_list=None):
         return None, None
 
     noise_field = None
-    for datatypedescr in dscfg['datatype']:
+    for datatypedescr in dscfg["datatype"]:
         radarnr, _, datatype, _, _ = get_datatype_fields(datatypedescr)
-        if datatype in ('IQhhADU', 'IQvvADU'):
+        if datatype in ("IQhhADU", "IQvvADU"):
             signal_field = get_fieldname_pyart(datatype)
-        elif datatype in ('IQNADUh', 'IQNADUv'):
+        elif datatype in ("IQNADUh", "IQNADUv"):
             noise_field = get_fieldname_pyart(datatype)
 
-    ind_rad = int(radarnr[5:8])-1
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
     if signal_field not in radar.fields:
-        warn('Unable to obtain Doppler spectrum width. ' +
-             'Missing field '+signal_field)
+        warn(
+            "Unable to obtain Doppler spectrum width. "
+            + "Missing field "
+            + signal_field
+        )
         return None, None
 
-    subtract_noise = dscfg.get('subtract_noise', False)
-    lag = dscfg.get('lag', 1)
+    dscfg.get("subtract_noise", False)
+    lag = dscfg.get("lag", 1)
 
     width = pyart.retrieve.compute_Doppler_width_iq(
-        radar, subtract_noise=True, signal_field=signal_field,
-        noise_field=noise_field, lag=lag)
+        radar,
+        subtract_noise=True,
+        signal_field=signal_field,
+        noise_field=noise_field,
+        lag=lag,
+    )
 
-    width_field = 'spectrum_width'
-    if signal_field == 'IQ_vv_ADU':
-        width_field += '_vv'
+    width_field = "spectrum_width"
+    if signal_field == "IQ_vv_ADU":
+        width_field += "_vv"
 
     # prepare for exit
-    new_dataset = {'radar_out': pyart.util.radar_from_spectra(radar)}
-    new_dataset['radar_out'].add_field(width_field, width)
+    new_dataset = {"radar_out": pyart.util.radar_from_spectra(radar)}
+    new_dataset["radar_out"].add_field(width_field, width)
 
     return new_dataset, ind_rad
 
@@ -812,7 +848,9 @@ def process_fft(procstatus, dscfg, radar_list=None):
         data set configuration. Accepted configuration keywords::
 
         datatype : list of string. Dataset keyword
-            The input data types
+            The input data types, must contain,
+            "IQNdBADUh" and/or "IQNdBADUv" and/or
+            "IQNADUh" and/or "IQNADUv" (see new_dataset below)
         window : list of str
             Parameters of the window used to obtain the spectra. The
             parameters are the ones corresponding to function
@@ -823,7 +861,11 @@ def process_fft(procstatus, dscfg, radar_list=None):
     Returns
     -------
     new_dataset : dict
-        dictionary containing the output
+        dictionary containing the output fields
+        "ShhADUu" (unfiltered_complex_spectra_hh_ADU) if IQNdBADUh was provided,
+        "SvvADUu" (unfiltered_complex_spectra_vv_ADU) if IQNdBADUv was provided,
+        "sNADUh" (spectral_noise_power_hh_ADU) if IQNADUh was provided,
+        "sNADUv" (spectral_noise_power_vv_ADU) if IQNADUv was provided,
     ind_rad : int
         radar index
 
@@ -832,17 +874,17 @@ def process_fft(procstatus, dscfg, radar_list=None):
     if procstatus != 1:
         return None, None
 
-    radarnr, _, datatype, _, _ = get_datatype_fields(dscfg['datatype'][0])
-    ind_rad = int(radarnr[5:8])-1
+    radarnr, _, datatype, _, _ = get_datatype_fields(dscfg["datatype"][0])
+    ind_rad = int(radarnr[5:8]) - 1
     if (radar_list is None) or (radar_list[ind_rad] is None):
-        warn('ERROR: No valid radar')
+        warn("ERROR: No valid radar")
         return None, None
     radar = radar_list[ind_rad]
 
-    wind_params = dscfg.get('window', ['None'])
+    wind_params = dscfg.get("window", ["None"])
     if len(wind_params) == 1:
         window = wind_params[0]
-        if window == 'None':
+        if window == "None":
             window = None
         else:
             try:
@@ -857,28 +899,29 @@ def process_fft(procstatus, dscfg, radar_list=None):
 
     fields_in_list = []
     fields_out_list = []
-    for datatypedescr in dscfg['datatype']:
+    for datatypedescr in dscfg["datatype"]:
         radarnr, _, datatype, _, _ = get_datatype_fields(datatypedescr)
         field_name = get_fieldname_pyart(datatype)
         if field_name not in radar.fields:
-            warn(field_name+' not in radar')
+            warn(field_name + " not in radar")
             continue
-        if field_name == 'IQ_hh_ADU':
-            fields_out_list.append('unfiltered_complex_spectra_hh_ADU')
-        elif field_name == 'IQ_vv_ADU':
-            fields_out_list.append('unfiltered_complex_spectra_vv_ADU')
-        elif field_name == 'IQ_noise_power_hh_ADU':
-            fields_out_list.append('spectral_noise_power_hh_ADU')
-        elif field_name == 'IQ_noiseADU_vv':
-            fields_out_list.append('spectral_noise_power_vv_ADU')
+        if field_name == "IQ_hh_ADU":
+            fields_out_list.append("unfiltered_complex_spectra_hh_ADU")
+        elif field_name == "IQ_vv_ADU":
+            fields_out_list.append("unfiltered_complex_spectra_vv_ADU")
+        elif field_name == "IQ_noise_power_hh_ADU":
+            fields_out_list.append("spectral_noise_power_hh_ADU")
+        elif field_name == "IQ_noiseADU_vv":
+            fields_out_list.append("spectral_noise_power_vv_ADU")
         else:
-            warn(field_name+' can not be Fourier transformed')
+            warn(field_name + " can not be Fourier transformed")
         fields_in_list.append(field_name)
 
     radar_out = pyart.retrieve.compute_spectra(
-        radar, fields_in_list, fields_out_list, window=window)
+        radar, fields_in_list, fields_out_list, window=window
+    )
 
     # prepare for exit
-    new_dataset = {'radar_out': radar_out}
+    new_dataset = {"radar_out": radar_out}
 
     return new_dataset, ind_rad
