@@ -73,6 +73,10 @@ import datetime
 import argparse
 import atexit
 import os
+import sys
+
+# Force unbuffered output
+sys.stdout.reconfigure(line_buffering=True)
 
 from pyrad.flow.flow_control import main_gecsx
 
@@ -101,19 +105,22 @@ def main():
         help='end time of the data to be processed. Format ''YYYYMMDDhhmmss''')
     parser.add_argument(
         '--cfgpath', type=str,
-        default=os.path.expanduser('~')+'/pyrad/config/processing/',
+        default=os.path.expanduser('~') + '/pyrad/config/processing/',
         help='configuration file path')
     parser.add_argument("-i", "--infostr", type=str,
                         help="Information string about the actual data "
                         "processing (e.g. 'RUN57'). This string is added "
                         "to the filenames of the product files.",
                         default="")
-    parser.add_argument("-g", "--gatherplots", type=int,
-                        help="If set to 1 will create a folder called ALL_FIGURES "
-                        "in the output folder as defined by saveimgbasepath "
-                        "in the main config file, and will copy all generated "
-                        "figures in this folder (for convenience)",
-                        default=1)
+    parser.add_argument(
+        "-g",
+        "--gatherplots",
+        type=int,
+        help="If set to 1 will create a folder called ALL_FIGURES "
+        "in the output folder as defined by saveimgbasepath "
+        "in the main config file, and will copy all generated "
+        "figures in this folder (for convenience)",
+        default=1)
     args = parser.parse_args()
 
     print("====== PYRAD data processing started: %s" %
@@ -121,14 +128,14 @@ def main():
     atexit.register(_print_end_msg,
                     "====== PYRAD data processing finished: ")
 
-    print('config path: '+args.cfgpath)
-    print('config file: '+args.proc_cfgfile)
+    print('config path: ' + args.cfgpath)
+    print('config file: ' + args.proc_cfgfile)
     if args.starttime is not None:
-        print('start time: '+args.starttime)
+        print('start time: ' + args.starttime)
     else:
         print('start time not defined by user')
     if args.endtime is not None:
-        print('end time: '+args.endtime)
+        print('end time: ' + args.endtime)
     else:
         print('end time not defined by user')
 
@@ -139,7 +146,7 @@ def main():
     proc_endtime = None
     if args.endtime is not None:
         proc_endtime = datetime.datetime.strptime(args.endtime, '%Y%m%d%H%M%S')
-    cfgfile_proc = args.cfgpath+args.proc_cfgfile
+    cfgfile_proc = args.cfgpath + args.proc_cfgfile
     gatherplots = args.gatherplots
     if args.infostr == 'None':
         infostr = ''
